<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Korean_Firefox
</name>

<description>
   <am>Korean localisation of Firefox</am>
   <ar>Korean localisation of Firefox</ar>
   <bg>Korean localisation of Firefox</bg>
   <ca>Localització de Firefox en Coreà</ca>
   <cs>Korean localisation of Firefox</cs>
   <da>Koreansk oversættelse af Firefox</da>
   <de>Koreanische Lokalisierung von Firefox</de>
   <el>Κορεατικός εντοπισμός του Firefox</el>
   <en>Korean localisation of Firefox</en>
   <es>Localización Coreana de Firefox</es>
   <et>Korean localisation of Firefox</et>
   <eu>Korean localisation of Firefox</eu>
   <fa>Korean localisation of Firefox</fa>
   <fi>Korean localisation of Firefox</fi>
   <fr>Localisation coréenne pour Firefox</fr>
   <he_IL>Korean localisation of Firefox</he_IL>
   <hi>Korean localisation of Firefox</hi>
   <hr>Korean localisation of Firefox</hr>
   <hu>Korean localisation of Firefox</hu>
   <id>Korean localisation of Firefox</id>
   <is>Korean localisation of Firefox</is>
   <it>Localizzazione coreana di Firefox</it>
   <ja_JP>Korean localisation of Firefox</ja_JP>
   <ja>Korean localisation of Firefox</ja>
   <kk>Korean localisation of Firefox</kk>
   <ko>Korean localisation of Firefox</ko>
   <lt>Korean localisation of Firefox</lt>
   <mk>Korean localisation of Firefox</mk>
   <nb>Korean localisation of Firefox</nb>
   <nl>Koreaanse lokalisatie van Firefox</nl>
   <pl>Koreańska lokalizacja przeglądarki Firefox</pl>
   <pt_BR>Coreano Localização para Firefox</pt_BR>
   <pt>Coreano Localização para Firefox</pt>
   <ro>Korean localisation of Firefox</ro>
   <ru>Корейская локализация Firefox</ru>
   <sk>Korean localisation of Firefox</sk>
   <sl>Korean localisation of Firefox</sl>
   <sq>Korean localisation of Firefox</sq>
   <sr>Korean localisation of Firefox</sr>
   <sv>Koreansk lokalisering av Firefox</sv>
   <tr>Korean localisation of Firefox</tr>
   <uk>Korean локалізація Firefox</uk>
   <zh_CN>Korean localisation of Firefox</zh_CN>
   <zh_TW>Korean localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-ko
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-ko
</uninstall_package_names>
</app>
